package cmdUser

import (
    "errors"
    u "nexus-client/utils"
    g "nexus-client/globals"
)

type ResetPwd struct {
    Name string
}

func (cmd *ResetPwd)GetName() string {
    return cmd.Name
}

func (cmd *ResetPwd)GetDesc() []string {
    return []string{
        "Reset password for one or more users.",
        "Requires USER_RESETPWD user capability."}
}

func (cmd *ResetPwd)PrintUsage() {
    for _, desc := range cmd.GetDesc() {
        u.PrintlnErr(desc)
    }
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("USAGE: "+cmd.GetName()+" email [email ...]")
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
}

func (cmd *ResetPwd)Run(args []string) int {
    argc := len(args)
    if argc < 1 {
        cmd.PrintUsage()
        return 1
    }

    statusCode := 0

    // Iterates through each user (email) and reset their password
    for i:= range(args) {
        email := args[i]
        resp, err := cmd.runRequest(email)
        if err != nil {
            u.PrintlnErr(err.Error())
            statusCode = 1
        } else {
            u.Println("New password for user "+email+": "+resp)
        }
    }

    return statusCode
}

func (cmd *ResetPwd)runRequest(email string) (string, error) {
    client := g.GetInstance().Client
    host := g.GetInstance().Host

    resp, err := client.R().Put(host+"/users/"+email+"/resetpwd")
    if err != nil {
        return "", errors.New("Error: "+err.Error())
    }

    if resp.IsSuccess() {
        return resp.String(), nil
    } else {
        return "", errors.New("Error: "+resp.Status()+": "+resp.String())
    }
}
